# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package='google.events.cloud.functions.v2',
    manifest={
        'Environment',
        'Function',
        'StateMessage',
        'StorageSource',
        'RepoSource',
        'Source',
        'SourceProvenance',
        'BuildConfig',
        'ServiceConfig',
        'SecretEnvVar',
        'SecretVolume',
        'EventTrigger',
        'EventFilter',
        'FunctionEventData',
    },
)


class Environment(proto.Enum):
    r"""The environment the function is hosted on.

    Values:
        ENVIRONMENT_UNSPECIFIED (0):
            Unspecified
        GEN_1 (1):
            Gen 1
        GEN_2 (2):
            Gen 2
    """
    ENVIRONMENT_UNSPECIFIED = 0
    GEN_1 = 1
    GEN_2 = 2


class Function(proto.Message):
    r"""Describes a Cloud Function that contains user computation
    executed in response to an event. It encapsulates function and
    trigger configurations.

    Attributes:
        name (str):
            A user-defined name of the function. Function names must be
            unique globally and match pattern
            ``projects/*/locations/*/functions/*``
        environment (google.events.cloud.functions_v2.types.Environment):
            Describe whether the function is gen1 or
            gen2.
        description (str):
            User-provided description of a function.
        build_config (google.events.cloud.functions_v2.types.BuildConfig):
            Describes the Build step of the function that
            builds a container from the given source.
        service_config (google.events.cloud.functions_v2.types.ServiceConfig):
            Describes the Service being deployed.
            Currently deploys services to Cloud Run (fully
            managed).
        event_trigger (google.events.cloud.functions_v2.types.EventTrigger):
            An Eventarc trigger managed by Google Cloud
            Functions that fires events in response to a
            condition in another service.
        state (google.events.cloud.functions_v2.types.Function.State):
            Output only. State of the function.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The last update timestamp of a
            Cloud Function.
        labels (MutableMapping[str, str]):
            Labels associated with this Cloud Function.
        state_messages (MutableSequence[google.events.cloud.functions_v2.types.StateMessage]):
            Output only. State Messages for this Cloud
            Function.
    """
    class State(proto.Enum):
        r"""Describes the current state of the function.

        Values:
            STATE_UNSPECIFIED (0):
                Not specified. Invalid state.
            ACTIVE (1):
                Function has been successfully deployed and
                is serving.
            FAILED (2):
                Function deployment failed and the function
                is not serving.
            DEPLOYING (3):
                Function is being created or updated.
            DELETING (4):
                Function is being deleted.
            UNKNOWN (5):
                Function deployment failed and the function
                serving state is undefined. The function should
                be updated or deleted to move it out of this
                state.
        """
        STATE_UNSPECIFIED = 0
        ACTIVE = 1
        FAILED = 2
        DEPLOYING = 3
        DELETING = 4
        UNKNOWN = 5

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    environment: 'Environment' = proto.Field(
        proto.ENUM,
        number=10,
        enum='Environment',
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    build_config: 'BuildConfig' = proto.Field(
        proto.MESSAGE,
        number=3,
        message='BuildConfig',
    )
    service_config: 'ServiceConfig' = proto.Field(
        proto.MESSAGE,
        number=4,
        message='ServiceConfig',
    )
    event_trigger: 'EventTrigger' = proto.Field(
        proto.MESSAGE,
        number=5,
        message='EventTrigger',
    )
    state: State = proto.Field(
        proto.ENUM,
        number=6,
        enum=State,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )
    state_messages: MutableSequence['StateMessage'] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message='StateMessage',
    )


class StateMessage(proto.Message):
    r"""Informational messages about the state of the Cloud Function
    or Operation.

    Attributes:
        severity (google.events.cloud.functions_v2.types.StateMessage.Severity):
            Severity of the state message.
        type_ (str):
            One-word CamelCase type of the state message.
        message (str):
            The message.
    """
    class Severity(proto.Enum):
        r"""Severity of the state message.

        Values:
            SEVERITY_UNSPECIFIED (0):
                Not specified. Invalid severity.
            ERROR (1):
                ERROR-level severity.
            WARNING (2):
                WARNING-level severity.
            INFO (3):
                INFO-level severity.
        """
        SEVERITY_UNSPECIFIED = 0
        ERROR = 1
        WARNING = 2
        INFO = 3

    severity: Severity = proto.Field(
        proto.ENUM,
        number=1,
        enum=Severity,
    )
    type_: str = proto.Field(
        proto.STRING,
        number=2,
    )
    message: str = proto.Field(
        proto.STRING,
        number=3,
    )


class StorageSource(proto.Message):
    r"""Location of the source in an archive file in Google Cloud
    Storage.

    Attributes:
        bucket (str):
            Google Cloud Storage bucket containing the source (see
            `Bucket Name
            Requirements <https://cloud.google.com/storage/docs/bucket-naming#requirements>`__).
        object_ (str):
            Google Cloud Storage object containing the source.

            This object must be a gzipped archive file (``.tar.gz``)
            containing source to build.
        generation (int):
            Google Cloud Storage generation for the
            object. If the generation is omitted, the latest
            generation will be used.
    """

    bucket: str = proto.Field(
        proto.STRING,
        number=1,
    )
    object_: str = proto.Field(
        proto.STRING,
        number=2,
    )
    generation: int = proto.Field(
        proto.INT64,
        number=3,
    )


class RepoSource(proto.Message):
    r"""Location of the source in a Google Cloud Source Repository.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        branch_name (str):
            Regex matching branches to build.
            The syntax of the regular expressions accepted
            is the syntax accepted by RE2 and described at
            https://github.com/google/re2/wiki/Syntax

            This field is a member of `oneof`_ ``revision``.
        tag_name (str):
            Regex matching tags to build.
            The syntax of the regular expressions accepted
            is the syntax accepted by RE2 and described at
            https://github.com/google/re2/wiki/Syntax

            This field is a member of `oneof`_ ``revision``.
        commit_sha (str):
            Explicit commit SHA to build.

            This field is a member of `oneof`_ ``revision``.
        project_id (str):
            ID of the project that owns the Cloud Source
            Repository. If omitted, the project ID
            requesting the build is assumed.
        repo_name (str):
            Name of the Cloud Source Repository.
        dir_ (str):
            Directory, relative to the source root, in which to run the
            build.

            This must be a relative path. If a step's ``dir`` is
            specified and is an absolute path, this value is ignored for
            that step's execution. eg. helloworld (no leading slash
            allowed)
        invert_regex (bool):
            Only trigger a build if the revision regex
            does NOT match the revision regex.
    """

    branch_name: str = proto.Field(
        proto.STRING,
        number=3,
        oneof='revision',
    )
    tag_name: str = proto.Field(
        proto.STRING,
        number=4,
        oneof='revision',
    )
    commit_sha: str = proto.Field(
        proto.STRING,
        number=5,
        oneof='revision',
    )
    project_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    repo_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    dir_: str = proto.Field(
        proto.STRING,
        number=6,
    )
    invert_regex: bool = proto.Field(
        proto.BOOL,
        number=7,
    )


class Source(proto.Message):
    r"""The location of the function source code.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        storage_source (google.events.cloud.functions_v2.types.StorageSource):
            If provided, get the source from this
            location in Google Cloud Storage.

            This field is a member of `oneof`_ ``source``.
        repo_source (google.events.cloud.functions_v2.types.RepoSource):
            If provided, get the source from this
            location in a Cloud Source Repository.

            This field is a member of `oneof`_ ``source``.
    """

    storage_source: 'StorageSource' = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof='source',
        message='StorageSource',
    )
    repo_source: 'RepoSource' = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof='source',
        message='RepoSource',
    )


class SourceProvenance(proto.Message):
    r"""Provenance of the source. Ways to find the original source,
    or verify that some source was used for this build.

    Attributes:
        resolved_storage_source (google.events.cloud.functions_v2.types.StorageSource):
            A copy of the build's ``source.storage_source``, if exists,
            with any generations resolved.
        resolved_repo_source (google.events.cloud.functions_v2.types.RepoSource):
            A copy of the build's ``source.repo_source``, if exists,
            with any revisions resolved.
    """

    resolved_storage_source: 'StorageSource' = proto.Field(
        proto.MESSAGE,
        number=1,
        message='StorageSource',
    )
    resolved_repo_source: 'RepoSource' = proto.Field(
        proto.MESSAGE,
        number=2,
        message='RepoSource',
    )


class BuildConfig(proto.Message):
    r"""Describes the Build step of the function that builds a
    container from the given source.

    Attributes:
        build (str):
            Output only. The Cloud Build name of the
            latest successful deployment of the function.
        runtime (str):
            The runtime in which to run the function. Required when
            deploying a new function, optional when updating an existing
            function. For a complete list of possible choices, see the
            ```gcloud`` command
            reference <https://cloud.google.com/sdk/gcloud/reference/functions/deploy#--runtime>`__.
        entry_point (str):
            The name of the function (as defined in source code) that
            will be executed. Defaults to the resource name suffix, if
            not specified. For backward compatibility, if function with
            given name is not found, then the system will try to use
            function named "function". For Node.js this is name of a
            function exported by the module specified in
            ``source_location``.
        source (google.events.cloud.functions_v2.types.Source):
            The location of the function source code.
        source_provenance (google.events.cloud.functions_v2.types.SourceProvenance):
            Output only. A permanent fixed identifier for
            source.
        worker_pool (str):
            Name of the Cloud Build Custom Worker Pool that should be
            used to build the function. The format of this field is
            ``projects/{project}/locations/{region}/workerPools/{workerPool}``
            where {project} and {region} are the project id and region
            respectively where the worker pool is defined and
            {workerPool} is the short name of the worker pool.

            If the project id is not the same as the function, then the
            Cloud Functions Service Agent
            (service-<project_number>@gcf-admin-robot.iam.gserviceaccount.com)
            must be granted the role Cloud Build Custom Workers Builder
            (roles/cloudbuild.customworkers.builder) in the project.
        environment_variables (MutableMapping[str, str]):
            User-provided build-time environment
            variables for the function
        docker_registry (google.events.cloud.functions_v2.types.BuildConfig.DockerRegistry):
            Optional. Docker Registry to use for this deployment. This
            configuration is only applicable to 1st Gen functions, 2nd
            Gen functions can only use Artifact Registry.

            If ``docker_repository`` field is specified, this field will
            be automatically set as ``ARTIFACT_REGISTRY``. If
            unspecified, it currently defaults to
            ``CONTAINER_REGISTRY``. This field may be overridden by the
            backend for eligible deployments.
        docker_repository (str):
            User managed repository created in Artifact Registry
            optionally with a customer managed encryption key. This is
            the repository to which the function docker image will be
            pushed after it is built by Cloud Build. If unspecified, GCF
            will create and use a repository named 'gcf-artifacts' for
            every deployed region.

            It must match the pattern
            ``projects/{project}/locations/{location}/repositories/{repository}``.

            Cross-project repositories are not supported. Cross-location
            repositories are not supported. Repository format must be
            'DOCKER'.
        buildpack_stack (str):
            Specifies one of the Google provided
            buildpack stacks.
    """
    class DockerRegistry(proto.Enum):
        r"""Docker Registry to use for storing function Docker images.

        Values:
            DOCKER_REGISTRY_UNSPECIFIED (0):
                Unspecified.
            CONTAINER_REGISTRY (1):
                Docker images will be stored in multi-regional Container
                Registry repositories named ``gcf``.
            ARTIFACT_REGISTRY (2):
                Docker images will be stored in regional Artifact Registry
                repositories. By default, GCF will create and use
                repositories named ``gcf-artifacts`` in every region in
                which a function is deployed. But the repository to use can
                also be specified by the user using the
                ``docker_repository`` field.
        """
        DOCKER_REGISTRY_UNSPECIFIED = 0
        CONTAINER_REGISTRY = 1
        ARTIFACT_REGISTRY = 2

    build: str = proto.Field(
        proto.STRING,
        number=1,
    )
    runtime: str = proto.Field(
        proto.STRING,
        number=2,
    )
    entry_point: str = proto.Field(
        proto.STRING,
        number=3,
    )
    source: 'Source' = proto.Field(
        proto.MESSAGE,
        number=4,
        message='Source',
    )
    source_provenance: 'SourceProvenance' = proto.Field(
        proto.MESSAGE,
        number=8,
        message='SourceProvenance',
    )
    worker_pool: str = proto.Field(
        proto.STRING,
        number=5,
    )
    environment_variables: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=6,
    )
    docker_registry: DockerRegistry = proto.Field(
        proto.ENUM,
        number=10,
        enum=DockerRegistry,
    )
    docker_repository: str = proto.Field(
        proto.STRING,
        number=7,
    )
    buildpack_stack: str = proto.Field(
        proto.STRING,
        number=9,
    )


class ServiceConfig(proto.Message):
    r"""Describes the Service being deployed.
    Currently Supported : Cloud Run (fully managed).
    Next tag: 23

    Attributes:
        service (str):
            Output only. Name of the service associated with a Function.
            The format of this field is
            ``projects/{project}/locations/{region}/services/{service}``
        timeout_seconds (int):
            The function execution timeout. Execution is
            considered failed and can be terminated if the
            function is not completed at the end of the
            timeout period. Defaults to 60 seconds.
        available_memory (str):
            The amount of memory available for a
            function. Defaults to 256M. Supported units are
            k, M, G, Mi, Gi. If no unit is supplied the
            value is interpreted as bytes.
            See
            https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
            a full description.
        available_cpu (str):
            The number of CPUs used in a single container
            instance. Default value is calculated from
            available memory. Supports the same values as
            Cloud Run, see
            https://cloud.google.com/run/docs/reference/rest/v1/Container#resourcerequirements
            Example: "1" indicates 1 vCPU
        environment_variables (MutableMapping[str, str]):
            Environment variables that shall be available
            during function execution.
        max_instance_count (int):
            The limit on the maximum number of function instances that
            may coexist at a given time.

            In some cases, such as rapid traffic surges, Cloud Functions
            may, for a short period of time, create more instances than
            the specified max instances limit. If your function cannot
            tolerate this temporary behavior, you may want to factor in
            a safety margin and set a lower max instances value than
            your function can tolerate.

            See the `Max
            Instances <https://cloud.google.com/functions/docs/max-instances>`__
            Guide for more details.
        min_instance_count (int):
            The limit on the minimum number of function
            instances that may coexist at a given time.

            Function instances are kept in idle state for a
            short period after they finished executing the
            request to reduce cold start time for subsequent
            requests. Setting a minimum instance count will
            ensure that the given number of instances are
            kept running in idle state always. This can help
            with cold start times when jump in incoming
            request count occurs after the idle instance
            would have been stopped in the default case.
        vpc_connector (str):
            The Serverless VPC Access connector that this cloud function
            can connect to. The format of this field is
            ``projects/*/locations/*/connectors/*``.
        vpc_connector_egress_settings (google.events.cloud.functions_v2.types.ServiceConfig.VpcConnectorEgressSettings):
            The egress settings for the connector,
            controlling what traffic is diverted through it.
        ingress_settings (google.events.cloud.functions_v2.types.ServiceConfig.IngressSettings):
            The ingress settings for the function,
            controlling what traffic can reach it.
        uri (str):
            Output only. URI of the Service deployed.
        service_account_email (str):
            The email of the service's service account. If empty,
            defaults to
            ``{project_number}-compute@developer.gserviceaccount.com``.
        all_traffic_on_latest_revision (bool):
            Whether 100% of traffic is routed to the
            latest revision. On CreateFunction and
            UpdateFunction, when set to true, the revision
            being deployed will serve 100% of traffic,
            ignoring any traffic split settings, if any. On
            GetFunction, true will be returned if the latest
            revision is serving 100% of traffic.
        secret_environment_variables (MutableSequence[google.events.cloud.functions_v2.types.SecretEnvVar]):
            Secret environment variables configuration.
        secret_volumes (MutableSequence[google.events.cloud.functions_v2.types.SecretVolume]):
            Secret volumes configuration.
        revision (str):
            Output only. The name of service revision.
        max_instance_request_concurrency (int):
            Sets the maximum number of concurrent
            requests that each instance can receive.
            Defaults to 1.
        security_level (google.events.cloud.functions_v2.types.ServiceConfig.SecurityLevel):
            Security level configure whether the function
            only accepts https. This configuration is only
            applicable to 1st Gen functions with Http
            trigger. By default https is optional for 1st
            Gen functions; 2nd Gen functions are https ONLY.
    """
    class VpcConnectorEgressSettings(proto.Enum):
        r"""Available egress settings.

        This controls what traffic is diverted through the VPC Access
        Connector resource. By default PRIVATE_RANGES_ONLY will be used.

        Values:
            VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED (0):
                Unspecified.
            PRIVATE_RANGES_ONLY (1):
                Use the VPC Access Connector only for private
                IP space from RFC1918.
            ALL_TRAFFIC (2):
                Force the use of VPC Access Connector for all
                egress traffic from the function.
        """
        VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED = 0
        PRIVATE_RANGES_ONLY = 1
        ALL_TRAFFIC = 2

    class IngressSettings(proto.Enum):
        r"""Available ingress settings.

        This controls what traffic can reach the function.

        If unspecified, ALLOW_ALL will be used.

        Values:
            INGRESS_SETTINGS_UNSPECIFIED (0):
                Unspecified.
            ALLOW_ALL (1):
                Allow HTTP traffic from public and private
                sources.
            ALLOW_INTERNAL_ONLY (2):
                Allow HTTP traffic from only private VPC
                sources.
            ALLOW_INTERNAL_AND_GCLB (3):
                Allow HTTP traffic from private VPC sources
                and through GCLB.
        """
        INGRESS_SETTINGS_UNSPECIFIED = 0
        ALLOW_ALL = 1
        ALLOW_INTERNAL_ONLY = 2
        ALLOW_INTERNAL_AND_GCLB = 3

    class SecurityLevel(proto.Enum):
        r"""Available security level settings.

        This enforces security protocol on function URL.

        Security level is only ocnfigurable for 1st Gen functions, If
        unspecified, SECURE_OPTIONAL will be used. 2nd Gen functions are
        SECURE_ALWAYS ONLY.

        Values:
            SECURITY_LEVEL_UNSPECIFIED (0):
                Unspecified.
            SECURE_ALWAYS (1):
                Requests for a URL that match this handler
                that do not use HTTPS are automatically
                redirected to the HTTPS URL with the same path.
                Query parameters are reserved for the redirect.
            SECURE_OPTIONAL (2):
                Both HTTP and HTTPS requests with URLs that
                match the handler succeed without redirects. The
                application can examine the request to determine
                which protocol was used and respond accordingly.
        """
        SECURITY_LEVEL_UNSPECIFIED = 0
        SECURE_ALWAYS = 1
        SECURE_OPTIONAL = 2

    service: str = proto.Field(
        proto.STRING,
        number=1,
    )
    timeout_seconds: int = proto.Field(
        proto.INT32,
        number=2,
    )
    available_memory: str = proto.Field(
        proto.STRING,
        number=13,
    )
    available_cpu: str = proto.Field(
        proto.STRING,
        number=22,
    )
    environment_variables: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    max_instance_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    min_instance_count: int = proto.Field(
        proto.INT32,
        number=12,
    )
    vpc_connector: str = proto.Field(
        proto.STRING,
        number=6,
    )
    vpc_connector_egress_settings: VpcConnectorEgressSettings = proto.Field(
        proto.ENUM,
        number=7,
        enum=VpcConnectorEgressSettings,
    )
    ingress_settings: IngressSettings = proto.Field(
        proto.ENUM,
        number=8,
        enum=IngressSettings,
    )
    uri: str = proto.Field(
        proto.STRING,
        number=9,
    )
    service_account_email: str = proto.Field(
        proto.STRING,
        number=10,
    )
    all_traffic_on_latest_revision: bool = proto.Field(
        proto.BOOL,
        number=16,
    )
    secret_environment_variables: MutableSequence['SecretEnvVar'] = proto.RepeatedField(
        proto.MESSAGE,
        number=17,
        message='SecretEnvVar',
    )
    secret_volumes: MutableSequence['SecretVolume'] = proto.RepeatedField(
        proto.MESSAGE,
        number=19,
        message='SecretVolume',
    )
    revision: str = proto.Field(
        proto.STRING,
        number=18,
    )
    max_instance_request_concurrency: int = proto.Field(
        proto.INT32,
        number=20,
    )
    security_level: SecurityLevel = proto.Field(
        proto.ENUM,
        number=21,
        enum=SecurityLevel,
    )


class SecretEnvVar(proto.Message):
    r"""Configuration for a secret environment variable. It has the
    information necessary to fetch the secret value from secret
    manager and expose it as an environment variable.

    Attributes:
        key (str):
            Name of the environment variable.
        project_id (str):
            Project identifier (preferably project number
            but can also be the project ID) of the project
            that contains the secret. If not set, it is
            assumed that the secret is in the same project
            as the function.
        secret (str):
            Name of the secret in secret manager (not the
            full resource name).
        version (str):
            Version of the secret (version number or the
            string 'latest'). It is recommended to use a
            numeric version for secret environment variables
            as any updates to the secret value is not
            reflected until new instances start.
    """

    key: str = proto.Field(
        proto.STRING,
        number=1,
    )
    project_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    secret: str = proto.Field(
        proto.STRING,
        number=3,
    )
    version: str = proto.Field(
        proto.STRING,
        number=4,
    )


class SecretVolume(proto.Message):
    r"""Configuration for a secret volume. It has the information
    necessary to fetch the secret value from secret manager and make
    it available as files mounted at the requested paths within the
    application container.

    Attributes:
        mount_path (str):
            The path within the container to mount the secret volume.
            For example, setting the mount_path as ``/etc/secrets``
            would mount the secret value files under the
            ``/etc/secrets`` directory. This directory will also be
            completely shadowed and unavailable to mount any other
            secrets. Recommended mount path: /etc/secrets
        project_id (str):
            Project identifier (preferably project number
            but can also be the project ID) of the project
            that contains the secret. If not set, it is
            assumed that the secret is in the same project
            as the function.
        secret (str):
            Name of the secret in secret manager (not the
            full resource name).
        versions (MutableSequence[google.events.cloud.functions_v2.types.SecretVolume.SecretVersion]):
            List of secret versions to mount for this secret. If empty,
            the ``latest`` version of the secret will be made available
            in a file named after the secret under the mount point.
    """

    class SecretVersion(proto.Message):
        r"""Configuration for a single version.

        Attributes:
            version (str):
                Version of the secret (version number or the string
                'latest'). It is preferable to use ``latest`` version with
                secret volumes as secret value changes are reflected
                immediately.
            path (str):
                Relative path of the file under the mount path where the
                secret value for this version will be fetched and made
                available. For example, setting the mount_path as
                '/etc/secrets' and path as ``secret_foo`` would mount the
                secret value file at ``/etc/secrets/secret_foo``.
        """

        version: str = proto.Field(
            proto.STRING,
            number=1,
        )
        path: str = proto.Field(
            proto.STRING,
            number=2,
        )

    mount_path: str = proto.Field(
        proto.STRING,
        number=1,
    )
    project_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    secret: str = proto.Field(
        proto.STRING,
        number=3,
    )
    versions: MutableSequence[SecretVersion] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=SecretVersion,
    )


class EventTrigger(proto.Message):
    r"""Describes EventTrigger, used to request events to be sent
    from another service.

    Attributes:
        trigger (str):
            Output only. The resource name of the Eventarc trigger. The
            format of this field is
            ``projects/{project}/locations/{region}/triggers/{trigger}``.
        trigger_region (str):
            The region that the trigger will be in. The
            trigger will only receive events originating in
            this region. It can be the same region as the
            function, a different region or multi-region, or
            the global region. If not provided, defaults to
            the same region as the function.
        event_type (str):
            Required. The type of event to observe. For example:
            ``google.cloud.audit.log.v1.written`` or
            ``google.cloud.pubsub.topic.v1.messagePublished``.
        event_filters (MutableSequence[google.events.cloud.functions_v2.types.EventFilter]):
            Criteria used to filter events.
        pubsub_topic (str):
            Optional. The name of a Pub/Sub topic in the same project
            that will be used as the transport topic for the event
            delivery. Format: ``projects/{project}/topics/{topic}``.

            This is only valid for events of type
            ``google.cloud.pubsub.topic.v1.messagePublished``. The topic
            provided here will not be deleted at function deletion.
        service_account_email (str):
            Optional. The email of the trigger's service account. The
            service account must have permission to invoke Cloud Run
            services, the permission is ``run.routes.invoke``. If empty,
            defaults to the Compute Engine default service account:
            ``{project_number}-compute@developer.gserviceaccount.com``.
        retry_policy (google.events.cloud.functions_v2.types.EventTrigger.RetryPolicy):
            Optional. If unset, then defaults to ignoring
            failures (i.e. not retrying them).
        channel (str):
            Optional. The name of the channel associated with the
            trigger in
            ``projects/{project}/locations/{location}/channels/{channel}``
            format. You must provide a channel to receive events from
            Eventarc SaaS partners.
    """
    class RetryPolicy(proto.Enum):
        r"""Describes the retry policy in case of function's execution
        failure. Retried execution is charged as any other execution.

        Values:
            RETRY_POLICY_UNSPECIFIED (0):
                Not specified.
            RETRY_POLICY_DO_NOT_RETRY (1):
                Do not retry.
            RETRY_POLICY_RETRY (2):
                Retry on any failure, retry up to 7 days with
                an exponential backoff (capped at 10 seconds).
        """
        RETRY_POLICY_UNSPECIFIED = 0
        RETRY_POLICY_DO_NOT_RETRY = 1
        RETRY_POLICY_RETRY = 2

    trigger: str = proto.Field(
        proto.STRING,
        number=1,
    )
    trigger_region: str = proto.Field(
        proto.STRING,
        number=2,
    )
    event_type: str = proto.Field(
        proto.STRING,
        number=3,
    )
    event_filters: MutableSequence['EventFilter'] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message='EventFilter',
    )
    pubsub_topic: str = proto.Field(
        proto.STRING,
        number=5,
    )
    service_account_email: str = proto.Field(
        proto.STRING,
        number=6,
    )
    retry_policy: RetryPolicy = proto.Field(
        proto.ENUM,
        number=7,
        enum=RetryPolicy,
    )
    channel: str = proto.Field(
        proto.STRING,
        number=8,
    )


class EventFilter(proto.Message):
    r"""Filters events based on exact matches on the CloudEvents
    attributes.

    Attributes:
        attribute (str):
            Required. The name of a CloudEvents
            attribute.
        value (str):
            Required. The value for the attribute.
        operator (str):
            Optional. The operator used for matching the events with the
            value of the filter. If not specified, only events that have
            an exact key-value pair specified in the filter are matched.
            The only allowed value is ``match-path-pattern``.
    """

    attribute: str = proto.Field(
        proto.STRING,
        number=1,
    )
    value: str = proto.Field(
        proto.STRING,
        number=2,
    )
    operator: str = proto.Field(
        proto.STRING,
        number=3,
    )


class FunctionEventData(proto.Message):
    r"""The data within all Function events.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        payload (google.events.cloud.functions_v2.types.Function):
            Optional. The Function event payload. Unset
            for deletion events.

            This field is a member of `oneof`_ ``_payload``.
    """

    payload: 'Function' = proto.Field(
        proto.MESSAGE,
        number=1,
        optional=True,
        message='Function',
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Parse and validate text-formatted Cloud Event payload data in a variety of
# google types.

import importlib
import os
import unittest

from util import make_test_case


class TestdataParsing(unittest.TestCase):
    """Load testdata files from $GOOGLE_EVENTS_TESTDATA directory and verify parsing."""

    def setUp(self) -> None:
        self.testdata_root = os.getenv("GOOGLE_EVENTS_TESTDATA", "")
        if self.testdata_root == "":
            self.skipTest("set GOOGLE_EVENTS_TESTDATA to run these tests")
        return super().setUp()

    # sorted the order files appear when running the following command in the testdata dir:
    # find . -type f -name '*.json' | sort
    def test_LogEntryData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/audit/v1/LogEntryData-bigqueryjobcompleted.json",
            ),
            "google.events.cloud.audit_v1",
            "LogEntryData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/audit/v1/LogEntryData-pubsubCreateTopic.json",
            ),
            "google.events.cloud.audit_v1",
            "LogEntryData",
        )()

    def test_BuildEventData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/cloudbuild/v1/BuildEventData-simple.json",
            ),
            "google.events.cloud.cloudbuild_v1",
            "BuildEventData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/cloudbuild/v1/BuildEventData-complex.json",
            ),
            "google.events.cloud.cloudbuild_v1",
            "BuildEventData",
        )()

    def test_DocumentEventData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/firestore/v1/DocumentEventData-simple.json",
            ),
            "google.events.cloud.firestore_v1",
            "DocumentEventData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/firestore/v1/DocumentEventData-complex.json",
            ),
            "google.events.cloud.firestore_v1",
            "DocumentEventData",
        )()

    def test_MessagePublishedData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/pubsub/v1/MessagePublishedData-text.json",
            ),
            "google.events.cloud.pubsub_v1",
            "MessagePublishedData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/pubsub/v1/MessagePublishedData-binary.json",
            ),
            "google.events.cloud.pubsub_v1",
            "MessagePublishedData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/pubsub/v1/MessagePublishedData-duplicatedFields.json",
            ),
            "google.events.cloud.pubsub_v1",
            "MessagePublishedData",
        )()

    def test_SchedulerJobData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/scheduler/v1/SchedulerJobData-simple.json",
            ),
            "google.events.cloud.scheduler_v1",
            "SchedulerJobData",
        )()

    def test_StorageObjectData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/storage/v1/StorageObjectData-simple.json",
            ),
            "google.events.cloud.storage_v1",
            "StorageObjectData",
        )()
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/cloud/storage/v1/StorageObjectData-complex.json",
            ),
            "google.events.cloud.storage_v1",
            "StorageObjectData",
        )()

    def test_AnalyticsLogData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/firebase/analytics/v1/AnalyticsLogData-complex.json",
            ),
            "google.events.firebase.analytics_v1",
            "AnalyticsLogData",
        )()

    def test_AuthEventData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/firebase/auth/v1/AuthEventData-complex.json",
            ),
            "google.events.firebase.auth_v1",
            "AuthEventData",
        )()

    def test_ReferenceEventData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/firebase/database/v1/ReferenceEventData-simple.json",
            ),
            "google.events.firebase.database_v1",
            "ReferenceEventData",
        )()

    def test_RemoteConfigEventData(self):
        make_test_case(
            os.path.join(
                self.testdata_root,
                "google/events/firebase/remoteconfig/v1/RemoteConfigEventData-simple.json",
            ),
            "google.events.firebase.remoteconfig_v1",
            "RemoteConfigEventData",
        )()


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import code_pb2  # type: ignore


__protobuf__ = proto.module(
    package='google.events.cloud.eventarc.v1',
    manifest={
        'Channel',
        'ChannelConnection',
        'Trigger',
        'EventFilter',
        'StateCondition',
        'Destination',
        'Transport',
        'CloudRun',
        'GKE',
        'Pubsub',
        'TriggerEventData',
        'ChannelEventData',
        'ChannelConnectionEventData',
    },
)


class Channel(proto.Message):
    r"""A representation of the Channel resource.
    A Channel is a resource on which event providers publish their
    events. The published events are delivered through the transport
    associated with the channel. Note that a channel is associated
    with exactly one event provider.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Required. The resource name of the channel. Must be unique
            within the location on the project and must be in
            ``projects/{project}/locations/{location}/channels/{channel_id}``
            format.
        uid (str):
            Output only. Server assigned unique
            identifier for the channel. The value is a UUID4
            string and guaranteed to remain unchanged until
            the resource is deleted.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The last-modified time.
        provider (str):
            The name of the event provider (e.g. Eventarc SaaS partner)
            associated with the channel. This provider will be granted
            permissions to publish events to the channel. Format:
            ``projects/{project}/locations/{location}/providers/{provider_id}``.
        pubsub_topic (str):
            Output only. The name of the Pub/Sub topic created and
            managed by Eventarc system as a transport for the event
            delivery. Format: ``projects/{project}/topics/{topic_id}``.

            This field is a member of `oneof`_ ``transport``.
        state (google.events.cloud.eventarc_v1.types.Channel.State):
            Output only. The state of a Channel.
        activation_token (str):
            Output only. The activation token for the
            channel. The token must be used by the provider
            to register the channel for publishing.
        crypto_key_name (str):
            Resource name of a KMS crypto key (managed by the user) used
            to encrypt/decrypt their event data.

            It must match the pattern
            ``projects/*/locations/*/keyRings/*/cryptoKeys/*``.
    """
    class State(proto.Enum):
        r"""State lists all the possible states of a Channel

        Values:
            STATE_UNSPECIFIED (0):
                Default value. This value is unused.
            PENDING (1):
                The PENDING state indicates that a Channel
                has been created successfully and there is a new
                activation token available for the subscriber to
                use to convey the Channel to the provider in
                order to create a Connection.
            ACTIVE (2):
                The ACTIVE state indicates that a Channel has
                been successfully connected with the event
                provider. An ACTIVE Channel is ready to receive
                and route events from the event provider.
            INACTIVE (3):
                The INACTIVE state indicates that the Channel
                cannot receive events permanently. There are two
                possible cases this state can happen:
                1. The SaaS provider disconnected from this
                Channel. 2. The Channel activation token has
                expired but the SaaS provider    wasn't
                connected.

                To re-establish a Connection with a provider,
                the subscriber should create a new Channel and
                give it to the provider.
        """
        STATE_UNSPECIFIED = 0
        PENDING = 1
        ACTIVE = 2
        INACTIVE = 3

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    uid: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    provider: str = proto.Field(
        proto.STRING,
        number=7,
    )
    pubsub_topic: str = proto.Field(
        proto.STRING,
        number=8,
        oneof='transport',
    )
    state: State = proto.Field(
        proto.ENUM,
        number=9,
        enum=State,
    )
    activation_token: str = proto.Field(
        proto.STRING,
        number=10,
    )
    crypto_key_name: str = proto.Field(
        proto.STRING,
        number=11,
    )


class ChannelConnection(proto.Message):
    r"""A representation of the ChannelConnection resource.
    A ChannelConnection is a resource which event providers create
    during the activation process to establish a connection between
    the provider and the subscriber channel.

    Attributes:
        name (str):
            Required. The name of the connection.
        uid (str):
            Output only. Server assigned ID of the
            resource. The server guarantees uniqueness and
            immutability until deleted.
        channel (str):
            Required. The name of the connected subscriber Channel. This
            is a weak reference to avoid cross project and cross
            accounts references. This must be in
            ``projects/{project}/location/{location}/channels/{channel_id}``
            format.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The last-modified time.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    uid: str = proto.Field(
        proto.STRING,
        number=2,
    )
    channel: str = proto.Field(
        proto.STRING,
        number=5,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )


class Trigger(proto.Message):
    r"""A representation of the trigger resource.

    Attributes:
        name (str):
            Required. The resource name of the trigger. Must be unique
            within the location of the project and must be in
            ``projects/{project}/locations/{location}/triggers/{trigger}``
            format.
        uid (str):
            Output only. Server-assigned unique
            identifier for the trigger. The value is a UUID4
            string and guaranteed to remain unchanged until
            the resource is deleted.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The last-modified time.
        event_filters (MutableSequence[google.events.cloud.eventarc_v1.types.EventFilter]):
            Required. Unordered list. The list of filters
            that applies to event attributes. Only events
            that match all the provided filters are sent to
            the destination.
        service_account (str):
            Optional. The IAM service account email associated with the
            trigger. The service account represents the identity of the
            trigger.

            The principal who calls this API must have the
            ``iam.serviceAccounts.actAs`` permission in the service
            account. See
            https://cloud.google.com/iam/docs/understanding-service-accounts?hl=en#sa_common
            for more information.

            For Cloud Run destinations, this service account is used to
            generate identity tokens when invoking the service. See
            https://cloud.google.com/run/docs/triggering/pubsub-push#create-service-account
            for information on how to invoke authenticated Cloud Run
            services. To create Audit Log triggers, the service account
            should also have the ``roles/eventarc.eventReceiver`` IAM
            role.
        destination (google.events.cloud.eventarc_v1.types.Destination):
            Required. Destination specifies where the
            events should be sent to.
        transport (google.events.cloud.eventarc_v1.types.Transport):
            Optional. To deliver messages, Eventarc might
            use other Google Cloud products as a transport
            intermediary. This field contains a reference to
            that transport intermediary. This information
            can be used for debugging purposes.
        labels (MutableMapping[str, str]):
            Optional. User labels attached to the
            triggers that can be used to group resources.
        channel (str):
            Optional. The name of the channel associated with the
            trigger in
            ``projects/{project}/locations/{location}/channels/{channel}``
            format. You must provide a channel to receive events from
            Eventarc SaaS partners.
        conditions (MutableMapping[str, google.events.cloud.eventarc_v1.types.StateCondition]):
            Output only. The reason(s) why a trigger is
            in FAILED state.
        event_data_content_type (str):
            Optional. EventDataContentType specifies the type of payload
            in MIME format that is expected from the CloudEvent data
            field. This is set to ``application/json`` if the value is
            not defined.
        etag (str):
            Output only. This checksum is computed by the
            server based on the value of other fields, and
            might be sent only on create requests to ensure
            that the client has an up-to-date value before
            proceeding.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    uid: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    event_filters: MutableSequence['EventFilter'] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message='EventFilter',
    )
    service_account: str = proto.Field(
        proto.STRING,
        number=9,
    )
    destination: 'Destination' = proto.Field(
        proto.MESSAGE,
        number=10,
        message='Destination',
    )
    transport: 'Transport' = proto.Field(
        proto.MESSAGE,
        number=11,
        message='Transport',
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=12,
    )
    channel: str = proto.Field(
        proto.STRING,
        number=13,
    )
    conditions: MutableMapping[str, 'StateCondition'] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=15,
        message='StateCondition',
    )
    event_data_content_type: str = proto.Field(
        proto.STRING,
        number=16,
    )
    etag: str = proto.Field(
        proto.STRING,
        number=99,
    )


class EventFilter(proto.Message):
    r"""Filters events based on exact matches on the CloudEvents
    attributes.

    Attributes:
        attribute (str):
            Required. The name of a CloudEvents
            attribute. Currently, only a subset of
            attributes are supported for filtering.
            All triggers MUST provide a filter for the
            'type' attribute.
        value (str):
            Required. The value for the attribute.
        operator (str):
            Optional. The operator used for matching the events with the
            value of the filter. If not specified, only events that have
            an exact key-value pair specified in the filter are matched.
            The only allowed value is ``match-path-pattern``.
    """

    attribute: str = proto.Field(
        proto.STRING,
        number=1,
    )
    value: str = proto.Field(
        proto.STRING,
        number=2,
    )
    operator: str = proto.Field(
        proto.STRING,
        number=3,
    )


class StateCondition(proto.Message):
    r"""A condition that is part of the trigger state computation.

    Attributes:
        code (google.rpc.code_pb2.Code):
            The canonical code of the condition.
        message (str):
            Human-readable message.
    """

    code: code_pb2.Code = proto.Field(
        proto.ENUM,
        number=1,
        enum=code_pb2.Code,
    )
    message: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Destination(proto.Message):
    r"""Represents a target of an invocation over HTTP.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        cloud_run (google.events.cloud.eventarc_v1.types.CloudRun):
            Cloud Run fully-managed resource that
            receives the events. The resource should be in
            the same project as the trigger.

            This field is a member of `oneof`_ ``descriptor``.
        cloud_function (str):
            The Cloud Function resource name. Only Cloud Functions V2 is
            supported. Format:
            ``projects/{project}/locations/{location}/functions/{function}``

            This is a read-only field. Creating Cloud Functions V2
            triggers is only supported via the Cloud Functions product.
            An error will be returned if the user sets this value.

            This field is a member of `oneof`_ ``descriptor``.
        gke (google.events.cloud.eventarc_v1.types.GKE):
            A GKE service capable of receiving events.
            The service should be running in the same
            project as the trigger.

            This field is a member of `oneof`_ ``descriptor``.
        workflow (str):
            The resource name of the Workflow whose Executions are
            triggered by the events. The Workflow resource should be
            deployed in the same project as the trigger. Format:
            ``projects/{project}/locations/{location}/workflows/{workflow}``

            This field is a member of `oneof`_ ``descriptor``.
    """

    cloud_run: 'CloudRun' = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof='descriptor',
        message='CloudRun',
    )
    cloud_function: str = proto.Field(
        proto.STRING,
        number=2,
        oneof='descriptor',
    )
    gke: 'GKE' = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof='descriptor',
        message='GKE',
    )
    workflow: str = proto.Field(
        proto.STRING,
        number=4,
        oneof='descriptor',
    )


class Transport(proto.Message):
    r"""Represents the transport intermediaries created for the
    trigger to deliver events.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        pubsub (google.events.cloud.eventarc_v1.types.Pubsub):
            The Pub/Sub topic and subscription used by
            Eventarc as a transport intermediary.

            This field is a member of `oneof`_ ``intermediary``.
    """

    pubsub: 'Pubsub' = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof='intermediary',
        message='Pubsub',
    )


class CloudRun(proto.Message):
    r"""Represents a Cloud Run destination.

    Attributes:
        service (str):
            Required. The name of the Cloud Run service
            being addressed. See
            https://cloud.google.com/run/docs/reference/rest/v1/namespaces.services.
            Only services located in the same project as the
            trigger object can be addressed.
        path (str):
            Optional. The relative path on the Cloud Run
            service the events should be sent to.

            The value must conform to the definition of a
            URI path segment (section 3.3 of RFC2396).
            Examples: "/route", "route", "route/subroute".
        region (str):
            Required. The region the Cloud Run service is
            deployed in.
    """

    service: str = proto.Field(
        proto.STRING,
        number=1,
    )
    path: str = proto.Field(
        proto.STRING,
        number=2,
    )
    region: str = proto.Field(
        proto.STRING,
        number=3,
    )


class GKE(proto.Message):
    r"""Represents a GKE destination.

    Attributes:
        cluster (str):
            Required. The name of the cluster the GKE
            service is running in. The cluster must be
            running in the same project as the trigger being
            created.
        location (str):
            Required. The name of the Google Compute
            Engine in which the cluster resides, which can
            either be compute zone (for example,
            us-central1-a) for the zonal clusters or region
            (for example, us-central1) for regional
            clusters.
        namespace (str):
            Required. The namespace the GKE service is
            running in.
        service (str):
            Required. Name of the GKE service.
        path (str):
            Optional. The relative path on the GKE
            service the events should be sent to.

            The value must conform to the definition of a
            URI path segment (section 3.3 of RFC2396).
            Examples: "/route", "route", "route/subroute".
    """

    cluster: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location: str = proto.Field(
        proto.STRING,
        number=2,
    )
    namespace: str = proto.Field(
        proto.STRING,
        number=3,
    )
    service: str = proto.Field(
        proto.STRING,
        number=4,
    )
    path: str = proto.Field(
        proto.STRING,
        number=5,
    )


class Pubsub(proto.Message):
    r"""Represents a Pub/Sub transport.

    Attributes:
        topic (str):
            Optional. The name of the Pub/Sub topic created and managed
            by Eventarc as a transport for the event delivery. Format:
            ``projects/{PROJECT_ID}/topics/{TOPIC_NAME}``.

            You can set an existing topic for triggers of the type
            ``google.cloud.pubsub.topic.v1.messagePublished``. The topic
            you provide here is not deleted by Eventarc at trigger
            deletion.
        subscription (str):
            Output only. The name of the Pub/Sub subscription created
            and managed by Eventarc as a transport for the event
            delivery. Format:
            ``projects/{PROJECT_ID}/subscriptions/{SUBSCRIPTION_NAME}``.
    """

    topic: str = proto.Field(
        proto.STRING,
        number=1,
    )
    subscription: str = proto.Field(
        proto.STRING,
        number=2,
    )


class TriggerEventData(proto.Message):
    r"""The data within all Trigger events.

    Attributes:
        payload (google.events.cloud.eventarc_v1.types.Trigger):
            The Trigger event payload.
    """

    payload: 'Trigger' = proto.Field(
        proto.MESSAGE,
        number=1,
        message='Trigger',
    )


class ChannelEventData(proto.Message):
    r"""The data within all Channel events.

    Attributes:
        payload (google.events.cloud.eventarc_v1.types.Channel):
            The Channel event payload.
    """

    payload: 'Channel' = proto.Field(
        proto.MESSAGE,
        number=1,
        message='Channel',
    )


class ChannelConnectionEventData(proto.Message):
    r"""The data within all ChannelConnection events.

    Attributes:
        payload (google.events.cloud.eventarc_v1.types.ChannelConnection):
            The ChannelConnection event payload.
    """

    payload: 'ChannelConnection' = proto.Field(
        proto.MESSAGE,
        number=1,
        message='ChannelConnection',
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore


__protobuf__ = proto.module(
    package='google.events.cloud.scheduler.v1',
    manifest={
        'SchedulerJobData',
    },
)


class SchedulerJobData(proto.Message):
    r"""Scheduler job data.

    Attributes:
        custom_data (bytes):
            The custom data the user specified when
            creating the scheduler source.
    """

    custom_data: bytes = proto.Field(
        proto.BYTES,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package='google.events.firebase.firebasealerts.v1',
    manifest={
        'AlertData',
    },
)


class AlertData(proto.Message):
    r"""The data within all Firebase Alerts.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Time that the event has created
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Time that the event has ended. Optional, only
            present for alertsthat are ongoing
        payload (google.protobuf.struct_pb2.Struct):
            Payload of the event, which includes the
            details of the specific alert. It's a map of
            keys of String type and values of various types
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    payload: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=3,
        message=struct_pb2.Struct,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Utility functions for writing tests for google-cloudevents

import importlib


def make_test_case(filename, pkg, cls):
    """Returns a test function that loads the given file as the supplied proto class."""

    def testfn():
        with open(filename) as f:
            raw_data = f.read()
        klass = getattr(importlib.import_module(pkg), cls)
        obj = klass.from_json(raw_data, ignore_unknown_fields=True)
        emptyobj = klass()
        assert obj != emptyobj
        return obj

    return testfn



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package='google.events.firebase.auth.v1',
    manifest={
        'AuthEventData',
        'UserMetadata',
        'UserInfo',
    },
)


class AuthEventData(proto.Message):
    r"""The data within all Firebase Auth events.

    Attributes:
        uid (str):
            The user identifier in the Firebase app.
        email (str):
            The user's primary email, if set.
        email_verified (bool):
            Whether or not the user's primary email is
            verified.
        display_name (str):
            The user's display name.
        photo_URL (str):
            The user's photo URL.
        disabled (bool):
            Whether the user is disabled.
        metadata (google.events.firebase.auth_v1.types.UserMetadata):
            Additional metadata about the user.
        provider_data (MutableSequence[google.events.firebase.auth_v1.types.UserInfo]):
            User's info at the providers
        phone_number (str):
            The user's phone number.
        custom_claims (google.protobuf.struct_pb2.Struct):
            User's custom claims, typically used to
            define user roles and propagated to an
            authenticated user's ID token.
    """

    uid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    email: str = proto.Field(
        proto.STRING,
        number=2,
    )
    email_verified: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=4,
    )
    photo_URL: str = proto.Field(
        proto.STRING,
        number=5,
    )
    disabled: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    metadata: 'UserMetadata' = proto.Field(
        proto.MESSAGE,
        number=7,
        message='UserMetadata',
    )
    provider_data: MutableSequence['UserInfo'] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message='UserInfo',
    )
    phone_number: str = proto.Field(
        proto.STRING,
        number=9,
    )
    custom_claims: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=10,
        message=struct_pb2.Struct,
    )


class UserMetadata(proto.Message):
    r"""Additional metadata about the user.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The date the user was created.
        last_sign_in_time (google.protobuf.timestamp_pb2.Timestamp):
            The date the user last signed in.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    last_sign_in_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )


class UserInfo(proto.Message):
    r"""User's info at the identity provider

    Attributes:
        uid (str):
            The user identifier for the linked provider.
        email (str):
            The email for the linked provider.
        display_name (str):
            The display name for the linked provider.
        photo_URL (str):
            The photo URL for the linked provider.
        provider_id (str):
            The linked provider ID (e.g. "google.com" for
            the Google provider).
    """

    uid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    email: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    photo_URL: str = proto.Field(
        proto.STRING,
        number=4,
    )
    provider_id: str = proto.Field(
        proto.STRING,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package='google.events.cloud.beyondcorp.clientgateways.v1',
    manifest={
        'ClientGateway',
        'ClientGatewayEventData',
    },
)


class ClientGateway(proto.Message):
    r"""Message describing ClientGateway object.

    Attributes:
        name (str):
            Required. name of resource. The name is
            ignored during creation.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. [Output only] Create time stamp.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. [Output only] Update time stamp.
        state (google.events.cloud.beyondcorp.clientgateways_v1.types.ClientGateway.State):
            Output only. The operational state of the
            gateway.
        id (str):
            Output only. A unique identifier for the
            instance generated by the system.
        client_connector_service (str):
            Output only. The client connector service name that the
            client gateway is associated to. Client Connector Services,
            named as follows:
            ``projects/{project_id}/locations/{location_id}/client_connector_services/{client_connector_service_id}``.
    """
    class State(proto.Enum):
        r"""Represents the different states of a gateway.

        Values:
            STATE_UNSPECIFIED (0):
                Default value. This value is unused.
            CREATING (1):
                Gateway is being created.
            UPDATING (2):
                Gateway is being updated.
            DELETING (3):
                Gateway is being deleted.
            RUNNING (4):
                Gateway is running.
            DOWN (5):
                Gateway is down and may be restored in the
                future. This happens when CCFE sends
                ProjectState = OFF.
            ERROR (6):
                ClientGateway encountered an error and is in
                indeterministic state.
        """
        STATE_UNSPECIFIED = 0
        CREATING = 1
        UPDATING = 2
        DELETING = 3
        RUNNING = 4
        DOWN = 5
        ERROR = 6

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=4,
        enum=State,
    )
    id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    client_connector_service: str = proto.Field(
        proto.STRING,
        number=6,
    )


class ClientGatewayEventData(proto.Message):
    r"""The data within all ClientGateway events.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        payload (google.events.cloud.beyondcorp.clientgateways_v1.types.ClientGateway):
            Optional. The ClientGateway event payload.
            Unset for deletion events.

            This field is a member of `oneof`_ ``_payload``.
    """

    payload: 'ClientGateway' = proto.Field(
        proto.MESSAGE,
        number=1,
        optional=True,
        message='ClientGateway',
    )


__all__ = tuple(sorted(__protobuf__.manifest))
